@@ -2,11 +2,26 @@
 use strict;
 use warnings;
 
-### TEST DATA ###
-
 my %tests = (
 
     hash => [
+        <<'EOM',
+        {
+            U => 2,
+            B => 52,
+        }
+EOM
+        <<'EOM',
+---
+- &1 !perl/hash
+  B: 52
+  U: 2
+- *1
+EOM
+        { load_only => 1 },
+    ],
+
+    hash_blessed => [
         <<'EOM',
         bless {
             U => 2,
@@ -23,6 +38,24 @@ EOM
     ],
 
     array => [
+        <<'EOM',
+        [
+            qw/ one two three four /
+        ]
+EOM
+        <<'EOM',
+---
+- &1 !perl/array
+  - one
+  - two
+  - three
+  - four
+- *1
+EOM
+        { load_only => 1 },
+    ],
+
+    array_blessed => [
         <<'EOM',
         bless [
             qw/ one two three four /
@@ -41,16 +74,26 @@ EOM
 
     regexp => [
         <<'EOM',
-        qr{unblessed}
+        my $string = 'unblessed';
+        qr{$string}
+EOM
+        <<"EOM",
+---
+- &1 !perl/regexp unblessed
+- *1
 EOM
-        qr{- &1 !perl/regexp .*unblessed.*- \*1}s,
     ],
 
     regexp_blessed => [
         <<'EOM',
-        bless qr{blessed}, "Foo"
+        my $string = 'blessed';
+        bless qr{$string}, "Foo"
+EOM
+        <<"EOM",
+---
+- &1 !perl/regexp:Foo blessed
+- *1
 EOM
-        qr{- &1 !perl/regexp:Foo .*blessed.*- \*1}s,
     ],
 
     circular => [
@@ -69,24 +112,26 @@ EOM
 EOM
     ],
 
-    code => [
+    coderef => [
         <<'EOM',
         sub {
-            my ($self, %args) = @_;
+            my (%args) = @_;
             return $args{x} + $args{y};
         }
 EOM
-        qr{- &1 !perl/code \|-.*return.*args.*x.*\+.*y}s,
+        qr{- &1 !{1,2}perl/code \|-.*return.*args.*x.*\+.*y}s,
+        { load_code => 1 },
     ],
 
-    code_blessed => [
+    coderef_blessed => [
         <<'EOM',
         bless sub {
-            my ($self, %args) = @_;
+            my (%args) = @_;
             return $args{x} - $args{y};
         }, "I::Am::Code"
 EOM
-        qr{- &1 !perl/code:I::Am::Code \|-.*return.*args.*x.*\-.*y}s,
+        qr{- &1 !{1,2}perl/code:I::Am::Code \|-.*return.*args.*x.*\-.*y}s,
+        { load_code => 1 },
     ],
 
     scalarref => [
@@ -147,6 +192,4 @@ EOM
     ],
 );
 
-### TEST DATA END ###
-
 \%tests;
